@@ -39,7 +39,7 @@
 #define __INTERNAL_CAPS_VISIBLE
 #include <term_entry.h>
 
-MODULE_ID("$Id: lib_termcap.c,v 1.36 2000/02/13 01:01:26 tom Exp $")
+MODULE_ID("$Id: lib_termcap.c,v 1.37 2000/09/16 20:30:16 tom Exp $")
 
 /*
    some of the code in here was contributed by:
@@ -190,19 +190,3 @@ tgetstr(NCURSES_CONST char *id, char **area)
     }
     returnPtr(NULL);
 }
-
-/*
- *	char *
- *	tgoto(string, x, y)
- *
- *	Retained solely for upward compatibility.  Note the intentional
- *	reversing of the last two arguments.
- *
- */
-
-char *
-tgoto(const char *string, int x, int y)
-{
-    T((T_CALLED("tgoto(%s,%d,%d)"), string, x, y));
-    returnPtr(tparm((NCURSES_CONST char *) string, y, x));
-}
