@@ -1,10 +1,10 @@
 /*
- * $Id: keynames.c,v 1.1 1997/10/25 18:41:04 tom Exp $
+ * $Id: keynames.c,v 1.2 1998/06/06 22:45:13 tom Exp $
  */
 
 #include <test.priv.h>
 
-int main(int argc, char *argv[])
+int main(int argc GCC_UNUSED, char *argv[] GCC_UNUSED)
 {
 	int n;
 	for (n = -1; n < 512; n++) {
